@@ -17,11 +17,15 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.Bookmark;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+
 /**
  * A service to manage bookmarks.
  *
@@ -55,6 +59,11 @@ public interface BookmarksService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(bookmark().name());
+            mandatory(bookmark().value());
+        }
         /**
          * The added bookmark.
          *
@@ -95,7 +104,7 @@ public interface BookmarksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         /**
          * The list of available bookmarks.
          *
