@@ -22,7 +22,7 @@ import org.ovirt.api.metamodel.annotations.Type;
 /**
  * Type representation of a cluster.
  *
- * A JSON representation of a cluster
+ * A JSON representation of a cluster:
  *
  * [source]
  * ----
@@ -58,6 +58,7 @@ import org.ovirt.api.metamodel.annotations.Type;
  *       }
  *     },
  *     "gluster_service" : "false",
+ *     "firewall_type" : "iptables",
  *     "ha_reservation" : "false",
  *     "ksm" : {
  *       "enabled" : "true",
@@ -138,14 +139,21 @@ import org.ovirt.api.metamodel.annotations.Type;
  *     }, {
  *       "href" : "/ovirt-engine/api/clusters/234/glustervolumes",
  *       "rel" : "glustervolumes"
+ *     }, {
+ *       "href" : "/ovirt-engine/api/clusters/234/enabledfeatures",
+ *       "rel" : "enabledfeatures"
+ *     }, {
+ *       "href" : "/ovirt-engine/api/clusters/234/externalnetworkproviders",
+ *       "rel" : "externalnetworkproviders"
  *     } ]
  *   } ]
  * }
  * ----
  *
  * @author Piotr Kliczewski <pkliczew@redhat.com>
- * @date 12 Dec 2016
- * @status added
+ * @author Tahlia Richardson <trichard@redhat.com>
+ * @date 06 Oct 2017
+ * @status updated_by_docs
  */
 @Type
 public interface Cluster extends Identified {
@@ -164,7 +172,7 @@ public interface Cluster extends Identified {
      * GET /ovirt-engine/api/clusters/123
      * ----
      *
-     * Will respond:
+     * Will respond with:
      *
      * [source,xml]
      * ----
@@ -185,7 +193,7 @@ public interface Cluster extends Identified {
      * PUT /ovirt-engine/api/clusters/123
      * ----
      *
-     * With a request body:
+     * With a request body like this:
      *
      * [source,xml]
      * ----
@@ -197,7 +205,8 @@ public interface Cluster extends Identified {
      * </cluster>
      * ----
      *
-     * In order to update the cluster compatibility version, all hosts in the cluster must support the new compatibility version.
+     * In order to update the cluster compatibility version, all hosts in the cluster must support
+     * the new compatibility version.
      *
      * @author Tomas Jelinek <tjelinek@redhat.com>
      * @author Byron Gravenorst <bgraveno@redhat.com>
@@ -249,16 +258,16 @@ public interface Cluster extends Identified {
     RngSource[] requiredRngSources();
 
     /**
-     * Custom fencing policy can be defined for a cluster.
+     * A custom fencing policy can be defined for a cluster.
      *
-     * Here is an example:
+     * For example:
      *
      * [source]
      * ----
      * PUT /ovirt-engine/api/cluster/123
      * ----
      *
-     * With request body:
+     * With request body like this:
      *
      * [source,xml]
      * ----
@@ -277,8 +286,9 @@ public interface Cluster extends Identified {
      * ----
      *
      * @author Oved Ourfali <oourfali@redhat.com>
-     * @date 29 Nov 2016
-     * @status added
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 06 Oct 2017
+     * @status updated_by_docs
      */
     FencingPolicy fencingPolicy();
     MigrationOptions migration();
@@ -325,7 +335,7 @@ public interface Cluster extends Identified {
     Property[] customSchedulingPolicyProperties();
 
     /**
-     * Type of switch to be used by all networks in given cluster.
+     * The type of switch to be used by all networks in given cluster.
      *
      * @author Byron Gravenorst <bgraveno@redhat.com>
      * @date 25 Oct 2016
@@ -333,12 +343,27 @@ public interface Cluster extends Identified {
      */
     SwitchType switchType();
 
+    /**
+     * The type of firewall to be used on hosts in this cluster.
+     *
+     * Up to version 4.1, it was always `iptables`. Since version 4.2, you can choose between `iptables` and `firewalld`.
+     * For clusters with a compatibility version of 4.2 and higher, the default firewall type is `firewalld`.
+     *
+     * @author Ondra Machacek <omachace@redhat.com>
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 11 Aug 2017
+     * @status updated_by_docs
+     * @since 4.2
+     */
+    FirewallType firewallType();
+
     /**
      * Custom features that are enabled for the cluster.
      *
      * @author Sahina Bose <sabose@redhat.com>
-     * @date 31 Jul 2017
-     * @status added
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 06 Oct 2017
+     * @status updated_by_docs
      * @since 4.1.6
      */
     @Link ClusterFeature[] enabledFeatures();
@@ -363,6 +388,25 @@ public interface Cluster extends Identified {
     @Link DataCenter dataCenter();
     @Link Network managementNetwork();
 
+    /**
+     * A reference to the external network provider available in the cluster.
+     *
+     * If the automatic deployment of the external network provider is supported,
+     * the networks of the referenced network provider are available on every host
+     * in the cluster.
+     * External network providers of a cluster can only be set during
+     * <<services/clusters/methods/add,adding the cluster>>.
+     * This value may be overwritten for individual hosts during
+     * <<services/hosts/methods/add,adding the host>>.
+     *
+     * @author Dominik Holler <dholler@redhat.com>
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 06 Oct 2017
+     * @status updated_by_docs
+     * @since 4.2
+     */
+    @Link ExternalProvider[] externalNetworkProviders();
+
     /**
      * A reference to the MAC pool used by this cluster.
      *
@@ -385,11 +429,12 @@ public interface Cluster extends Identified {
     /**
      * The name of the https://fedorahosted.org/tuned[tuned] profile
      * to set on all the hosts in the cluster. This is not mandatory
-     * and relevant only for clusters with gluster service.
+     * and relevant only for clusters with Gluster service.
      *
      * @author Ramesh Nachimuthu <rnachimu@rednat.com>
-     * @date 28 Oct 2016
-     * @status added
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 06 Oct 2017
+     * @status updated_by_docs
      * @since 4.1
      */
     String glusterTunedProfile();
