@@ -17,6 +17,7 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -25,7 +26,16 @@ import types.Hook;
 @Service
 @Area("Virtualization")
 public interface HostHooksService {
-    interface List {
+    /**
+     * Returns the list of hooks configured for the host.
+     *
+     * The order of the returned list of hooks isn't guranteed.
+     *
+     * @author Juan Hernandez <juan.hernandez@redhat.com>
+     * @date 15 Apr 2017
+     * @status added
+     */
+    interface List extends Follow {
         @Out Hook[] hooks();
 
         /**
