@@ -17,6 +17,7 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -29,7 +30,16 @@ public interface VmDisksService {
         @In @Out Disk disk();
     }
 
-    interface List {
+    /**
+     * Returns the list of disks of the virtual machine.
+     *
+     * The order of the returned list of disks isn't guaranteed.
+     *
+     * @author Juan Hernandez <juan.hernandez@redhat.com>
+     * @date 15 Apr 2017
+     * @status added
+     */
+    interface List extends Follow {
         @Out Disk[] disks();
 
         /**
