@@ -44,7 +44,6 @@ import org.ovirt.engine.sdk4.types.Tag;
 import org.ovirt.engine.sdk4.types.Template;
 import org.ovirt.engine.sdk4.types.TimeZone;
 import org.ovirt.engine.sdk4.types.Vm;
-import org.ovirt.engine.sdk4.types.VmPlacementPolicy;
 import org.ovirt.engine.sdk4.types.VmPool;
 import org.ovirt.engine.sdk4.types.VmStatus;
 import org.ovirt.engine.sdk4.types.Watchdog;
@@ -57,7 +56,6 @@ public class VmContainer extends VmBaseContainer implements Vm {
     private Boolean nextRunConfigurationExists;
     private NumaTuneMode numaTuneMode;
     private List<Payload> payloads;
-    private VmPlacementPolicy placementPolicy;
     private Boolean runOnce;
     private Date startTime;
     private VmStatus status;
@@ -181,18 +179,6 @@ public class VmContainer extends VmBaseContainer implements Vm {
         return payloads != null && !payloads.isEmpty();
     }
     
-    public VmPlacementPolicy placementPolicy() {
-        return placementPolicy;
-    }
-    
-    public void placementPolicy(VmPlacementPolicy newPlacementPolicy) {
-        placementPolicy = newPlacementPolicy;
-    }
-    
-    public boolean placementPolicyPresent() {
-        return placementPolicy != null;
-    }
-    
     public boolean runOnce() {
         return runOnce;
     }
