@@ -99,7 +99,9 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlCpuProfileReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.profile(XmlCpuProfileReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
     private class AddResponseImpl implements AddResponse {
         private CpuProfile profile;
         
-        public AddResponseImpl(CpuProfile profile) {
+        public void profile(CpuProfile profile) {
             this.profile = profile;
         }
         
@@ -190,7 +192,9 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlCpuProfileReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.profiles(XmlCpuProfileReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +205,7 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +214,7 @@ public class AssignedCpuProfilesServiceImpl extends ServiceImpl implements Assig
     private class ListResponseImpl implements ListResponse {
         private List<CpuProfile> profiles;
         
-        public ListResponseImpl(List<CpuProfile> profiles) {
+        public void profiles(List<CpuProfile> profiles) {
             this.profiles = profiles;
         }
         
