@@ -99,7 +99,9 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlBookmarkReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.bookmark(XmlBookmarkReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
     private class AddResponseImpl implements AddResponse {
         private Bookmark bookmark;
         
-        public AddResponseImpl(Bookmark bookmark) {
+        public void bookmark(Bookmark bookmark) {
             this.bookmark = bookmark;
         }
         
@@ -190,7 +192,9 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlBookmarkReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.bookmarks(XmlBookmarkReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +205,7 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +214,7 @@ public class BookmarksServiceImpl extends ServiceImpl implements BookmarksServic
     private class ListResponseImpl implements ListResponse {
         private List<Bookmark> bookmarks;
         
-        public ListResponseImpl(List<Bookmark> bookmarks) {
+        public void bookmarks(List<Bookmark> bookmarks) {
             this.bookmarks = bookmarks;
         }
         
