@@ -99,7 +99,9 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlPermitReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.permit(XmlPermitReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
     private class AddResponseImpl implements AddResponse {
         private Permit permit;
         
-        public AddResponseImpl(Permit permit) {
+        public void permit(Permit permit) {
             this.permit = permit;
         }
         
@@ -190,7 +192,9 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlPermitReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.permits(XmlPermitReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +205,7 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +214,7 @@ public class PermitsServiceImpl extends ServiceImpl implements PermitsService {
     private class ListResponseImpl implements ListResponse {
         private List<Permit> permits;
         
-        public ListResponseImpl(List<Permit> permits) {
+        public void permits(List<Permit> permits) {
             this.permits = permits;
         }
         
