@@ -379,7 +379,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             HttpResponse response = getConnection().send(request);
             Action action = checkAction(response);
             EntityUtils.consumeQuietly(response.getEntity());
-            return new FenceResponseImpl(action.powerManagement());
+            FenceResponseImpl actionResponse = new FenceResponseImpl();
+            actionResponse.powerManagement(action.powerManagement());
+            return actionResponse;
         }
         
     }
@@ -387,7 +389,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class FenceResponseImpl implements FenceResponse {
         private PowerManagement powerManagement;
         
-        public FenceResponseImpl(PowerManagement powerManagement) {
+        public void powerManagement(PowerManagement powerManagement) {
             this.powerManagement = powerManagement;
         }
         
@@ -501,7 +503,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlHostReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -512,7 +516,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -521,7 +525,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class GetResponseImpl implements GetResponse {
         private Host host;
         
-        public GetResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
@@ -675,15 +679,28 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             HttpResponse response = getConnection().send(request);
             Action action = checkAction(response);
             EntityUtils.consumeQuietly(response.getEntity());
-            return new IscsiDiscoverResponseImpl(action.iscsiTargets());
+            IscsiDiscoverResponseImpl actionResponse = new IscsiDiscoverResponseImpl();
+            actionResponse.iscsiTargets(action.iscsiTargets());
+            actionResponse.discoveredTargets(action.discoveredTargets());
+            return actionResponse;
         }
         
     }
     
     private class IscsiDiscoverResponseImpl implements IscsiDiscoverResponse {
+        private List<IscsiDetails> discoveredTargets;
+        
+        public void discoveredTargets(List<IscsiDetails> discoveredTargets) {
+            this.discoveredTargets = discoveredTargets;
+        }
+        
+        public List<IscsiDetails> discoveredTargets() {
+            return discoveredTargets;
+        }
+        
         private List<String> iscsiTargets;
         
-        public IscsiDiscoverResponseImpl(List<String> iscsiTargets) {
+        public void iscsiTargets(List<String> iscsiTargets) {
             this.iscsiTargets = iscsiTargets;
         }
         
@@ -1058,6 +1075,50 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
         return new SetupNetworksRequestImpl();
     }
     
+    private class SyncAllNetworksRequestImpl extends BaseRequest<SyncAllNetworksRequest, SyncAllNetworksResponse> implements SyncAllNetworksRequest {
+        private Boolean async;
+        public SyncAllNetworksRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        public SyncAllNetworksResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/syncallnetworks");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new SyncAllNetworksResponseImpl();
+        }
+        
+    }
+    
+    private class SyncAllNetworksResponseImpl implements SyncAllNetworksResponse {
+    }
+    
+    public SyncAllNetworksRequest syncAllNetworks() {
+        return new SyncAllNetworksRequestImpl();
+    }
+    
     private class UnregisteredStorageDomainsDiscoverRequestImpl extends BaseRequest<UnregisteredStorageDomainsDiscoverRequest, UnregisteredStorageDomainsDiscoverResponse> implements UnregisteredStorageDomainsDiscoverRequest {
         private Boolean async;
         public UnregisteredStorageDomainsDiscoverRequest async(Boolean async) {
@@ -1102,7 +1163,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             HttpResponse response = getConnection().send(request);
             Action action = checkAction(response);
             EntityUtils.consumeQuietly(response.getEntity());
-            return new UnregisteredStorageDomainsDiscoverResponseImpl(action.storageDomains());
+            UnregisteredStorageDomainsDiscoverResponseImpl actionResponse = new UnregisteredStorageDomainsDiscoverResponseImpl();
+            actionResponse.storageDomains(action.storageDomains());
+            return actionResponse;
         }
         
     }
@@ -1110,7 +1173,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class UnregisteredStorageDomainsDiscoverResponseImpl implements UnregisteredStorageDomainsDiscoverResponse {
         private List<StorageDomain> storageDomains;
         
-        public UnregisteredStorageDomainsDiscoverResponseImpl(List<StorageDomain> storageDomains) {
+        public void storageDomains(List<StorageDomain> storageDomains) {
             this.storageDomains = storageDomains;
         }
         
@@ -1184,7 +1247,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlHostReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -1195,7 +1260,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -1204,7 +1269,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class UpdateResponseImpl implements UpdateResponse {
         private Host host;
         
-        public UpdateResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
@@ -1537,7 +1602,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateUsingRootPasswordResponseImpl(XmlHostReader.readOne(reader));
+                    UpdateUsingRootPasswordResponseImpl actionResponse = new UpdateUsingRootPasswordResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -1548,7 +1615,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             }
             else {
                 checkFault(response);
-                return new UpdateUsingRootPasswordResponseImpl(null);
+                return new UpdateUsingRootPasswordResponseImpl();
             }
         }
         
@@ -1557,7 +1624,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class UpdateUsingRootPasswordResponseImpl implements UpdateUsingRootPasswordResponse {
         private Host host;
         
-        public UpdateUsingRootPasswordResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
@@ -1795,7 +1862,9 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateUsingSshResponseImpl(XmlHostReader.readOne(reader));
+                    UpdateUsingSshResponseImpl actionResponse = new UpdateUsingSshResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -1806,7 +1875,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
             }
             else {
                 checkFault(response);
-                return new UpdateUsingSshResponseImpl(null);
+                return new UpdateUsingSshResponseImpl();
             }
         }
         
@@ -1815,7 +1884,7 @@ public class HostServiceImpl extends MeasurableServiceImpl implements HostServic
     private class UpdateUsingSshResponseImpl implements UpdateUsingSshResponse {
         private Host host;
         
-        public UpdateUsingSshResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
