@@ -117,7 +117,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlHostReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -128,7 +130,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -137,7 +139,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     private class AddResponseImpl implements AddResponse {
         private Host host;
         
-        public AddResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
@@ -244,7 +246,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlHostReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.hosts(XmlHostReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -255,7 +259,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -264,7 +268,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     private class ListResponseImpl implements ListResponse {
         private List<Host> hosts;
         
-        public ListResponseImpl(List<Host> hosts) {
+        public void hosts(List<Host> hosts) {
             this.hosts = hosts;
         }
         
@@ -349,7 +353,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddUsingRootPasswordResponseImpl(XmlHostReader.readOne(reader));
+                    AddUsingRootPasswordResponseImpl actionResponse = new AddUsingRootPasswordResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -360,7 +366,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             }
             else {
                 checkFault(response);
-                return new AddUsingRootPasswordResponseImpl(null);
+                return new AddUsingRootPasswordResponseImpl();
             }
         }
         
@@ -369,7 +375,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     private class AddUsingRootPasswordResponseImpl implements AddUsingRootPasswordResponse {
         private Host host;
         
-        public AddUsingRootPasswordResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
@@ -454,7 +460,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddUsingSshResponseImpl(XmlHostReader.readOne(reader));
+                    AddUsingSshResponseImpl actionResponse = new AddUsingSshResponseImpl();
+                    actionResponse.host(XmlHostReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -465,7 +473,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             }
             else {
                 checkFault(response);
-                return new AddUsingSshResponseImpl(null);
+                return new AddUsingSshResponseImpl();
             }
         }
         
@@ -474,7 +482,7 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     private class AddUsingSshResponseImpl implements AddUsingSshResponse {
         private Host host;
         
-        public AddUsingSshResponseImpl(Host host) {
+        public void host(Host host) {
             this.host = host;
         }
         
