@@ -20,6 +20,7 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.net.URISyntaxException;
 import java.util.List;
+import java.util.Map;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
@@ -28,6 +29,7 @@ import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
 import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
+import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.OpenstackVolumeAuthenticationKeyBuilder;
@@ -44,7 +46,7 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
         super(connection, path);
     }
     
-    private class AddRequestImpl implements AddRequest {
+    private class AddRequestImpl extends BaseRequest<AddRequest, AddResponse> implements AddRequest {
         private OpenstackVolumeAuthenticationKey key;
         public AddRequest key(OpenstackVolumeAuthenticationKey key) {
             this.key = key;
@@ -60,6 +62,11 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
             HttpPost request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpPost(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
@@ -77,6 +84,12 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
                 throw new Error("Failed to parse response", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -86,7 +99,9 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlOpenstackVolumeAuthenticationKeyReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.key(XmlOpenstackVolumeAuthenticationKeyReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -97,7 +112,7 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -106,7 +121,7 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
     private class AddResponseImpl implements AddResponse {
         private OpenstackVolumeAuthenticationKey key;
         
-        public AddResponseImpl(OpenstackVolumeAuthenticationKey key) {
+        public void key(OpenstackVolumeAuthenticationKey key) {
             this.key = key;
         }
         
@@ -120,7 +135,13 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
         return new AddRequestImpl();
     }
     
-    private class ListRequestImpl implements ListRequest {
+    private class ListRequestImpl extends BaseRequest<ListRequest, ListResponse> implements ListRequest {
+        private String follow;
+        public ListRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         private BigInteger max;
         public ListRequest max(BigInteger max) {
             this.max = max;
@@ -141,15 +162,29 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
             HttpGet request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpGet(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -157,7 +192,9 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlOpenstackVolumeAuthenticationKeyReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.keys(XmlOpenstackVolumeAuthenticationKeyReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -168,7 +205,7 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -177,7 +214,7 @@ public class OpenstackVolumeAuthenticationKeysServiceImpl extends ServiceImpl im
     private class ListResponseImpl implements ListResponse {
         private List<OpenstackVolumeAuthenticationKey> keys;
         
-        public ListResponseImpl(List<OpenstackVolumeAuthenticationKey> keys) {
+        public void keys(List<OpenstackVolumeAuthenticationKey> keys) {
             this.keys = keys;
         }
         
