@@ -99,7 +99,9 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlQuotaClusterLimitReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.limit(XmlQuotaClusterLimitReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
     private class AddResponseImpl implements AddResponse {
         private QuotaClusterLimit limit;
         
-        public AddResponseImpl(QuotaClusterLimit limit) {
+        public void limit(QuotaClusterLimit limit) {
             this.limit = limit;
         }
         
@@ -190,7 +192,9 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlQuotaClusterLimitReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.limits(XmlQuotaClusterLimitReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +205,7 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +214,7 @@ public class QuotaClusterLimitsServiceImpl extends ServiceImpl implements QuotaC
     private class ListResponseImpl implements ListResponse {
         private List<QuotaClusterLimit> limits;
         
-        public ListResponseImpl(List<QuotaClusterLimit> limits) {
+        public void limits(List<QuotaClusterLimit> limits) {
             this.limits = limits;
         }
         
