@@ -19,12 +19,14 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.net.URISyntaxException;
 import java.util.List;
+import java.util.Map;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.utils.URIBuilder;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
 import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
+import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.internal.HttpConnection;
@@ -39,7 +41,13 @@ public class VmSessionsServiceImpl extends ServiceImpl implements VmSessionsServ
         super(connection, path);
     }
     
-    private class ListRequestImpl implements ListRequest {
+    private class ListRequestImpl extends BaseRequest<ListRequest, ListResponse> implements ListRequest {
+        private String follow;
+        public ListRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         private BigInteger max;
         public ListRequest max(BigInteger max) {
             this.max = max;
@@ -60,15 +68,29 @@ public class VmSessionsServiceImpl extends ServiceImpl implements VmSessionsServ
             HttpGet request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpGet(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -76,7 +98,9 @@ public class VmSessionsServiceImpl extends ServiceImpl implements VmSessionsServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlSessionReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.sessions(XmlSessionReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -87,7 +111,7 @@ public class VmSessionsServiceImpl extends ServiceImpl implements VmSessionsServ
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -96,7 +120,7 @@ public class VmSessionsServiceImpl extends ServiceImpl implements VmSessionsServ
     private class ListResponseImpl implements ListResponse {
         private List<Session> sessions;
         
-        public ListResponseImpl(List<Session> sessions) {
+        public void sessions(List<Session> sessions) {
             this.sessions = sessions;
         }
         
