@@ -225,6 +225,9 @@ public class XmlActionWriter {
         if (object.rootPasswordPresent()) {
             writer.writeElement("root_password", object.rootPassword());
         }
+        if (object.sealPresent()) {
+            writer.writeBoolean("seal", object.seal());
+        }
         if (object.snapshotPresent()) {
             XmlSnapshotWriter.writeOne(object.snapshot(), "snapshot", writer);
         }
