@@ -24,6 +24,10 @@ public interface GraphicsConsole extends Identified {
     boolean addressPresent();
     
     BigInteger port();
+    Byte portAsByte();
+    Short portAsShort();
+    Integer portAsInteger();
+    Long portAsLong();
     
     boolean portPresent();
     
@@ -32,6 +36,10 @@ public interface GraphicsConsole extends Identified {
     boolean protocolPresent();
     
     BigInteger tlsPort();
+    Byte tlsPortAsByte();
+    Short tlsPortAsShort();
+    Integer tlsPortAsInteger();
+    Long tlsPortAsLong();
     
     boolean tlsPortPresent();
     
